@@ -9,7 +9,7 @@ def notify(to, subject="", text=""):
     mailObject['text'] = text
     mailObject['to'] = ', '.join(to)
 
-    x = requests.post("hrrp://localhost:3000/send-noti", json = mailObject)
+    x = requests.post("http://localhost:3000/send-noti", json = mailObject)
 
     if x.status_code == 200:
         print("Notification sent")
